@@ -151,6 +151,7 @@ typedef enum {
  * @E_CONTENT_EDITOR_INSERT_TEXT_HTML:
  * @E_CONTENT_EDITOR_INSERT_TEXT_PLAIN:
  * @E_CONTENT_EDITOR_INSERT_CONVERT_PREFER_PRE: Set when should convert plain text into &lt;pre&gt; instead of &lt;div&gt;. Since 3.40
+ * @E_CONTENT_EDITOR_INSERT_CLEANUP_SIGNATURE_ID: Set when should cleanup signature ID in the body. Since 3.42
  *
  * Since: 3.22
  **/
@@ -161,7 +162,8 @@ typedef enum {
 	E_CONTENT_EDITOR_INSERT_REPLACE_ALL		= 1 << 2,
 	E_CONTENT_EDITOR_INSERT_TEXT_HTML		= 1 << 3,
 	E_CONTENT_EDITOR_INSERT_TEXT_PLAIN		= 1 << 4,
-	E_CONTENT_EDITOR_INSERT_CONVERT_PREFER_PRE	= 1 << 5
+	E_CONTENT_EDITOR_INSERT_CONVERT_PREFER_PRE	= 1 << 5,
+	E_CONTENT_EDITOR_INSERT_CLEANUP_SIGNATURE_ID	= 1 << 6
 } EContentEditorInsertContentFlags;
 
 /**
@@ -523,6 +525,28 @@ typedef enum {
 	E_CONTENT_EDITOR_FIND_WRAP_AROUND	= 1 << 4
 } EContentEditorFindFlags;
 
+/**
+ * EContentEditorMode:
+ * @E_CONTENT_EDITOR_MODE_UNKNOWN: unknown mode
+ * @E_CONTENT_EDITOR_MODE_PLAIN_TEXT: plain text, expects export as text/plain
+ * @E_CONTENT_EDITOR_MODE_HTML: HTML, expects export as text/html
+ * @E_CONTENT_EDITOR_MODE_MARKDOWN: markdown, expects export as text/markdown
+ * @E_CONTENT_EDITOR_MODE_MARKDOWN_PLAIN_TEXT: markdown, expects export as text/plain
+ * @E_CONTENT_EDITOR_MODE_MARKDOWN_HTML: markdown, expects export as text/html
+ *
+ * Editing mode of a content editor.
+ *
+ * Since: 3.44
+ **/
+typedef enum {
+	E_CONTENT_EDITOR_MODE_UNKNOWN = -1,
+	E_CONTENT_EDITOR_MODE_PLAIN_TEXT,
+	E_CONTENT_EDITOR_MODE_HTML,
+	E_CONTENT_EDITOR_MODE_MARKDOWN,
+	E_CONTENT_EDITOR_MODE_MARKDOWN_PLAIN_TEXT,
+	E_CONTENT_EDITOR_MODE_MARKDOWN_HTML
+} EContentEditorMode;
+
 /**
  * EUndoRedoState:
  * @E_UNDO_REDO_STATE_NONE: Cannot undo, neither redo.
@@ -618,6 +642,28 @@ typedef enum {
  **/
 #define E_CONFIG_LOOKUP_RESULT_LAST_KIND E_CONFIG_LOOKUP_RESULT_TASK_LIST
 
+/**
+ * EMarkdownHTMLToTextFlags:
+ * @E_MARKDOWN_HTML_TO_TEXT_FLAG_NONE: no flag set
+ * @E_MARKDOWN_HTML_TO_TEXT_FLAG_PLAIN_TEXT: disallow any HTML, save in pure plain text
+ * @E_MARKDOWN_HTML_TO_TEXT_FLAG_COMPOSER_QUIRKS: enable composer quirks to post-process the text
+ *
+ * Flags used in e_markdown_util_html_to_text().
+ *
+ * Since: 3.44
+ **/
+typedef enum { /*< flags >*/
+	E_MARKDOWN_HTML_TO_TEXT_FLAG_NONE		= 0,
+	E_MARKDOWN_HTML_TO_TEXT_FLAG_PLAIN_TEXT		= 1 << 0,
+	E_MARKDOWN_HTML_TO_TEXT_FLAG_COMPOSER_QUIRKS	= 1 << 1
+} EMarkdownHTMLToTextFlags;
+
+typedef enum {
+	E_TOOLBAR_ICON_SIZE_DEFAULT	= 0,
+	E_TOOLBAR_ICON_SIZE_SMALL	= 1,
+	E_TOOLBAR_ICON_SIZE_LARGE	= 2
+} EToolbarIconSize;
+
 G_END_DECLS
 
 #endif /* E_UTIL_ENUMS_H */
